@@ -17,7 +17,6 @@
 //!
 //! ### Test that `cargo build -q` runs successfully and has empty output without normalization
 //! ```
-//! use std::process::Command;
 //! use tryrun::prelude::*;
 //!
 //! Command::cargo("build").arg("-q").run_pass(OutputStr::empty(), normalize::noop());
@@ -25,7 +24,6 @@
 //!
 //! ### Test that `rustc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
-//! use std::process::Command;
 //! use tryrun::prelude::*;
 //!
 //! Command::rustc().arg("-V").run_pass(
@@ -40,7 +38,6 @@
 //!
 //! ### Test that `rustdoc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
-//! use std::process::Command;
 //! use tryrun::prelude::*;
 //!
 //! Command::rustdoc().arg("-V").run_pass(
@@ -55,7 +52,6 @@
 //!
 //! ### Test that `clippy-driver -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
-//! use std::process::Command;
 //! use tryrun::prelude::*;
 //!
 //! Command::new("clippy-driver").rustc_like().arg("-V").run_pass(
@@ -70,7 +66,6 @@
 //!
 //! ### Test that `false` runs unsucessfully and has empty output without normalization
 //! ```
-//! use std::process::Command;
 //! use tryrun::prelude::*;
 //!
 //! Command::new("false").run_fail(OutputStr::empty(), normalize::noop());
@@ -78,7 +73,6 @@
 //!
 //! ### Test that `false garbage` also runs unsucessfully and has empty output without normalization
 //! ```
-//! use std::process::Command;
 //! use tryrun::prelude::*;
 //!
 //! Command::new("false").arg("garbage").run_fail(OutputStr::empty(), normalize::noop());
@@ -728,6 +722,7 @@ impl CommandExt for Command {
 /// ```
 pub mod prelude {
     pub use super::{normalize, CommandExt as _, Normalizer, Output, OutputStr};
+    pub use std::process::Command;
 }
 
 #[cfg(test)]
